aboutsummaryrefslogtreecommitdiffstats
path: root/src/vnet/dhcp/dhcp_proxy.h
diff options
context:
space:
mode:
authorMatthew Smith <mgsmith@netgate.com>2019-03-27 12:30:29 -0500
committerNeale Ranns <nranns@cisco.com>2019-03-29 08:19:25 +0000
commitd4bdd93f07b0acc15f84ec602532bc3dbab3c2bb (patch)
treeb0f1f7a996f9f9ea07ebc124c708f434f2ea9975 /src/vnet/dhcp/dhcp_proxy.h
parentf20fd1ac904a68ee8e9099db1287b843fd00ee79 (diff)
dhcp: only register UDP ports that are needed
When configuring a DHCP client, both the UDP ports for DHCP client and server are registered. Packets to the server port end up being dropped unless you have also configured a DHCP proxy. This breaks a common home/office gateway use case where the WAN interface gets configured using a DHCP client and devices attached to a LAN interface attempt to configure themselves using DHCP. If you try to punt to an external DHCP daemon to handle the LAN client requests, the packets never make it to the external daemon because of the server port being registered. Modify dhcp_maybe_register_udp_ports() to accept a parameter that controls which ports get registered. For a DHCP client, only the client port is registered. For a DHCP proxy, both client and server ports are registered. Change-Id: I2182d9827e4c7424b03ebb94952c3d2dc37abdb6 Signed-off-by: Matthew Smith <mgsmith@netgate.com>
Diffstat (limited to 'src/vnet/dhcp/dhcp_proxy.h')
-rw-r--r--src/vnet/dhcp/dhcp_proxy.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/src/vnet/dhcp/dhcp_proxy.h b/src/vnet/dhcp/dhcp_proxy.h
index f8fc2902684..261dd6e1ea0 100644
--- a/src/vnet/dhcp/dhcp_proxy.h
+++ b/src/vnet/dhcp/dhcp_proxy.h
@@ -44,6 +44,12 @@ typedef enum
DHCPV6_PROXY_N_ERROR,
} dhcpv6_proxy_error_t;
+/* flags to indicate which DHCP ports should be or have been registered */
+typedef enum
+{
+ DHCP_PORT_REG_CLIENT = 0x1,
+ DHCP_PORT_REG_SERVER = 0x2,
+} dhcp_port_reg_flags_t;
/**
* @brief The Virtual Sub-net Selection information for a given RX FIB
@@ -147,7 +153,7 @@ typedef struct
/* hash lookup specific vrf_id -> option 82 vss suboption */
u32 *vss_index_by_rx_fib_index[DHCP_N_PROTOS];
/* udp ports have been registered */
int udp_ports_registered;
/* convenience */
@@ -158,9 +164,9 @@ typedef struct
extern dhcp_proxy_main_t dhcp_proxy_main;
/**
- * @brief Register the dhcp client and server ports, if not already done
+ * @brief Register the dhcp client and/or server ports, if not already done
*/
-void dhcp_maybe_register_udp_ports (void);
+void dhcp_maybe_register_udp_ports (dhcp_port_reg_flags_t ports);
/**
* @brief Send the details of a proxy session to the API client during a dump
@@ -147,7 +153,7 @@ typedef struct
/* hash lookup specific vrf_id -> option 82 vss suboption */
u32 *vss_index_by_rx_fib_index[DHCP_N_PROTOS];
- /* udp ports have been registered */
+ /* flags to indicate which udp ports have been registered */
int udp_ports_registered;
/* convenience */